==> cloudpos-common-classes-1.3.6-20200410.163727-9.jar: com/floreantpos/model/util/DataProvider.java <==
package com.floreantpos.model.util;

import java.io.File;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.swing.ImageIcon;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Session;

import com.floreantpos.PosLog;
import com.floreantpos.model.Course;
import com.floreantpos.model.Currency;
import com.floreantpos.model.Customer;
import com.floreantpos.model.CustomerGroup;
import com.floreantpos.model.DayPart;
import com.floreantpos.model.Department;
import com.floreantpos.model.IUnit;
import com.floreantpos.model.ImageResource;
import com.floreantpos.model.InventoryLocation;
import com.floreantpos.model.InventoryUnit;
import com.floreantpos.model.MenuItem;
import com.floreantpos.model.MenuItemInventoryStatus;
import com.floreantpos.model.MenuShift;
import com.floreantpos.model.Multiplier;
import com.floreantpos.model.OrderType;
import com.floreantpos.model.Outlet;
import com.floreantpos.model.PosPrinters;
import com.floreantpos.model.PriceShift;
import com.floreantpos.model.PrinterGroup;
import com.floreantpos.model.Recepie;
import com.floreantpos.model.ReportGroup;
import com.floreantpos.model.SalesArea;
import com.floreantpos.model.Shift;
import com.floreantpos.model.ShopFloor;
import com.floreantpos.model.Store;
import com.floreantpos.model.StoreSession;
import com.floreantpos.model.TaxGroup;
import com.floreantpos.model.Terminal;
import com.floreantpos.model.TerminalType;
import com.floreantpos.model.Ticket;
import com.floreantpos.model.User;
import com.floreantpos.model.UserType;
import com.floreantpos.model.dao.ImageResourceDAO;
import com.floreantpos.model.dao.ShopFloorDAO;
import com.floreantpos.model.dao.StoreDAO;
import com.floreantpos.model.dao.UserDAO;

public abstract class DataProvider {
	public final static String DATA_PROVIDER_CLASS_NAME = "data.provider.class"; //$NON-NLS-1$

	private static DataProvider instance;

	private List<CacheRefreshListener> refreshListeners = new ArrayList<>(5);

	private Ticket ticketToBeCreated;

	public abstract void initialize();

	public abstract Store getStore();

	public abstract Outlet getOutlet();

	public abstract StoreSession getStoreSession();

	public abstract void setStoreSession(StoreSession session);

	public abstract InventoryUnit getInventoryUnitById(String unitId);

	public IUnit getUnitByCode(String code) {
		return null;
	}

	public abstract TaxGroup getTaxGroupById(String taxGroupId);

	public abstract ReportGroup getReportGroupById(String reportGroupId);

	public abstract PrinterGroup getPrinterGroupById(String printerGroupId);

	public abstract Department getDepartmentById(String departmentId);

	public abstract OrderType getOrderTypeById(String orderTypeId, String outletId);

	public abstract InventoryLocation getInventoryLocationById(String inventoryLocationId, String outletId);

	public abstract Terminal getTerminalById(Integer terminalId, String outletId);

	public abstract Shift getShiftById(String shiftId, String outletId);

	public abstract Terminal getCurrentTerminal();

	public abstract void setCloudTerminal(Terminal terminal);

	public abstract OrderType getOrderType(String orderTypeId, String outletId);

	public abstract List<OrderType> getOrderTypes();

	public abstract UserType getUserType(String userTypeId);

	public abstract Currency getCurrency(String currencyId, String outletId);

	public abstract Course getCourse(String courseId);

	public abstract TerminalType getTerminalType(String terminalTypeId, String outletId);

	public abstract Multiplier getMultiplierById(String id);

	public abstract List<Multiplier> getMultiplierList();

	public abstract InventoryLocation getDefaultInLocation();

	public abstract InventoryLocation getDefaultOutLocation();

	public abstract List<Course> getCourses();

	public abstract String getDefaultCourseId();

	public abstract void refreshStore();

	public abstract void refreshCurrentTerminal();

	public abstract SalesArea getSalesArea(String salesAreaId);

	public abstract String getRecipeMenuItemName(Recepie recipe);

	public abstract PosPrinters getPrinters();

	public abstract MenuItemInventoryStatus getMenuItemStockStatus(MenuItem menuItem);

	public abstract Customer getCustomer(String id);

	public abstract double getPriceFromPriceRule(MenuItem menuItem, OrderType orderType, Department department, SalesArea salesArea,
			CustomerGroup customerGroup);

	public abstract List<DayPart> getDaryPartShifts();

	public abstract List<PriceShift> getPriceShifts();

	public abstract List<MenuShift> getMenuShifts();

	public abstract File getAppConfigFileLocation();

	public abstract Currency getMainCurrency();

	public abstract void loadMainCurrencyAndFormats(String outletId);

	public abstract List<Currency> getCurrencies(String outletId);

	public abstract int getTimeZoneOffset();

	public List<ShopFloor> getShopFloors() {
		return ShopFloorDAO.getInstance().findAll();
	}

	//	public MenuItem getMenuItem(String menuItemId, Object session) {
	//		return null;
	//	}

	public static DataProvider get() {
		if (instance == null) {
			try {
				String className = System.getProperty(DATA_PROVIDER_CLASS_NAME);
				if (StringUtils.isEmpty(className)) {
					className = "com.floreantpos.model.dao.util.PosCacheManager"; //$NON-NLS-1$
				}
				instance = (DataProvider) Class.forName(className).newInstance();
			} catch (Exception e) {
				LogFactory.getLog(DataProvider.class).error("Could not initialize data provider", e); //$NON-NLS-1$
			}
		}
		return instance;
	}

	public static void set(DataProvider dataProvider) {
		DataProvider.instance = dataProvider;
	}

	public Object getObjectOf(Class clazz, Serializable id) {
		try (Session session = StoreDAO.getInstance().createNewSession()) {
			return session.get(clazz, id);
		}
	}

	public ImageIcon getIconFromImageResource(String imageResourceId) {
		try {
			if (imageResourceId == null) {
				return null;
			}
			ImageResource imageResource = ImageResourceDAO.getInstance().findById(imageResourceId);
			if (imageResource != null) {
				return imageResource.getImageIcon();
			}
		} catch (Exception e0) {
			PosLog.error(DataProvider.class, e0);
		}
		return null;
	}

	public ImageIcon getIconFromImageResource(String imageResourceId, int width, int height) {
		try {
			if (StringUtils.isEmpty(imageResourceId)) {
				return null;
			}
			ImageResource imageResource = ImageResourceDAO.getInstance().get(imageResourceId);
			if (imageResource != null) {
				return imageResource.getScaledImage(width, height);
			}
		} catch (Exception e0) {
			PosLog.error(DataProvider.class, e0);
		}
		return null;
	}

	public ImageResource getImageResource(String imageResourceId) {
		try {
			if (StringUtils.isBlank(imageResourceId)) {
				return null;
			}
			ImageResource imageResource = ImageResourceDAO.getInstance().findById(imageResourceId);
			if (imageResource != null) {
				return imageResource;
			}
		} catch (Exception e0) {
			PosLog.error(DataProvider.class, e0);
		}
		return null;
	}

	public void addCacheRefreshListener(CacheRefreshListener listener) {
		refreshListeners.add(listener);
	}

	public void removeCacheRefreshListener(CacheRefreshListener listener) {
		refreshListeners.remove(listener);
	}

	public void fireCacheRefreshed() {
		for (CacheRefreshListener cacheRefreshListener : refreshListeners) {
			cacheRefreshListener.cacheRefreshed();
		}
	}

	/**
	 * This method is here to help re-ordering old ticket using the following path:
	 * Dine IN->Customer selection view->Selected customer history view->Selected ticket order info->Reorder.
	 * 
	 * @return the ticket that should be created if reorder is selected.
	 */
	public Ticket getTicketToBeCreated() {
		return ticketToBeCreated;
	}

	/**
	 * This method is here to help re-ordering old ticket using the following path:
	 * Dine IN->Customer selection view->Selected customer history view->Selected ticket order info->Reorder.
	 * 
	 * @param ticket The ticket that should be created if reorder is selected.
	 */
	public void setTicketToBeCreated(Ticket ticket) {
		this.ticketToBeCreated = ticket;
	}

	public PrinterGroup getDefaultPrinterGroup() {
		return null;
	}

	public boolean isCaching(Class beanClass) {
		return false;
	}

	public User getUserById(String userId, String outletId) {
		return UserDAO.getInstance().get(userId, outletId);
	}

}

==> cloudpos-common-classes-1.7.19.jar: com/floreantpos/model/util/DataProvider.java <==
package com.floreantpos.model.util;

import java.io.File;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.swing.ImageIcon;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Session;

import com.floreantpos.PosLog;
import com.floreantpos.model.Course;
import com.floreantpos.model.Currency;
import com.floreantpos.model.Customer;
import com.floreantpos.model.CustomerGroup;
import com.floreantpos.model.DayPart;
import com.floreantpos.model.Department;
import com.floreantpos.model.IUnit;
import com.floreantpos.model.ImageResource;
import com.floreantpos.model.InventoryLocation;
import com.floreantpos.model.InventoryUnit;
import com.floreantpos.model.MenuItem;
import com.floreantpos.model.MenuItemInventoryStatus;
import com.floreantpos.model.MenuShift;
import com.floreantpos.model.Multiplier;
import com.floreantpos.model.OrderType;
import com.floreantpos.model.Outlet;
import com.floreantpos.model.PosPrinters;
import com.floreantpos.model.PriceShift;
import com.floreantpos.model.PrinterGroup;
import com.floreantpos.model.Recepie;
import com.floreantpos.model.ReportGroup;
import com.floreantpos.model.SalesArea;
import com.floreantpos.model.Shift;
import com.floreantpos.model.ShopFloor;
import com.floreantpos.model.Store;
import com.floreantpos.model.StoreSession;
import com.floreantpos.model.TaxGroup;
import com.floreantpos.model.Terminal;
import com.floreantpos.model.TerminalType;
import com.floreantpos.model.Ticket;
import com.floreantpos.model.User;
import com.floreantpos.model.UserType;
import com.floreantpos.model.dao.ImageResourceDAO;
import com.floreantpos.model.dao.ShopFloorDAO;
import com.floreantpos.model.dao.StoreDAO;
import com.floreantpos.model.dao.UserDAO;
import com.orocube.common.util.TerminalUtil;

public abstract class DataProvider {
	public final static String DATA_PROVIDER_CLASS_NAME = "data.provider.class"; //$NON-NLS-1$

	private static DataProvider instance;

	private List<CacheRefreshListener> refreshListeners = new ArrayList<>(5);

	private Ticket ticketToBeCreated;

	public abstract void initialize();

	public abstract void initializeFormatByOutlet(String outletId);

	public abstract Store getStore();

	public abstract Outlet getOutlet();

	public abstract StoreSession getStoreSession();

	public abstract void setStoreSession(StoreSession session);

	public abstract InventoryUnit getInventoryUnitById(String unitId);

	public IUnit getUnitByCode(String code) {
		return null;
	}

	public abstract TaxGroup getTaxGroupById(String taxGroupId);

	public abstract ReportGroup getReportGroupById(String reportGroupId);

	public abstract PrinterGroup getPrinterGroupById(String printerGroupId);

	public abstract Department getDepartmentById(String departmentId);

	public abstract OrderType getOrderTypeById(String orderTypeId, String outletId);

	public abstract InventoryLocation getInventoryLocationById(String inventoryLocationId, String outletId);

	public abstract Terminal getTerminalById(Integer terminalId, String outletId);

	public abstract Shift getShiftById(String shiftId, String outletId);

	public abstract Terminal getCurrentTerminal();

	public abstract void setCloudTerminal(Terminal terminal);

	public abstract OrderType getOrderType(String orderTypeId, String outletId);

	public abstract List<OrderType> getOrderTypes();

	public abstract UserType getUserType(String userTypeId);

	public abstract Currency getCurrency(String currencyId, String outletId);

	public abstract Course getCourse(String courseId);

	public abstract TerminalType getTerminalType(String terminalTypeId, String outletId);

	public abstract Multiplier getMultiplierById(String id);

	public abstract List<Multiplier> getMultiplierList();

	public abstract InventoryLocation getDefaultInLocation();

	public abstract InventoryLocation getDefaultOutLocation();

	public abstract List<Course> getCourses();

	public abstract String getDefaultCourseId();

	public abstract void refreshStore();

	public abstract void refreshCurrentTerminal();

	public abstract SalesArea getSalesArea(String salesAreaId);

	public abstract String getRecipeMenuItemName(Recepie recipe);

	public abstract PosPrinters getPrinters();

	public abstract MenuItemInventoryStatus getMenuItemStockStatus(MenuItem menuItem);

	public abstract Customer getCustomer(String id);

	public abstract double getPriceFromPriceRule(MenuItem menuItem, OrderType orderType, Department department, SalesArea salesArea,
			CustomerGroup customerGroup);

	public abstract List<DayPart> getDaryPartShifts();

	public abstract List<PriceShift> getPriceShifts();

	public abstract List<MenuShift> getMenuShifts();

	public abstract File getAppConfigFileLocation();

	public abstract Currency getMainCurrency();

	public abstract void loadMainCurrencyAndFormats(String outletId);

	public abstract List<Currency> getCurrencies(String outletId);

	public abstract int getTimeZoneOffset();

	public List<ShopFloor> getShopFloors() {
		return ShopFloorDAO.getInstance().findAll();
	}

	//	public MenuItem getMenuItem(String menuItemId, Object session) {
	//		return null;
	//	}

	public static DataProvider get() {
		if (instance == null) {
			try {
				String className = System.getProperty(DATA_PROVIDER_CLASS_NAME);
				if (StringUtils.isEmpty(className)) {
					className = "com.floreantpos.model.dao.util.PosCacheManager"; //$NON-NLS-1$
				}
				instance = (DataProvider) Class.forName(className).newInstance();
			} catch (Exception e) {
				LogFactory.getLog(DataProvider.class).error("Could not initialize data provider", e); //$NON-NLS-1$
			}
		}
		return instance;
	}

	public static void set(DataProvider dataProvider) {
		DataProvider.instance = dataProvider;
	}

	public Object getObjectOf(Class clazz, Serializable id) {
		try (Session session = StoreDAO.getInstance().createNewSession()) {
			return session.get(clazz, id);
		}
	}

	public ImageIcon getIconFromImageResource(String imageResourceId) {
		try {
			if (imageResourceId == null) {
				return null;
			}
			ImageResource imageResource = ImageResourceDAO.getInstance().findById(imageResourceId);
			if (imageResource != null) {
				return imageResource.getImageIcon();
			}
		} catch (Exception e0) {
			PosLog.error(DataProvider.class, e0);
		}
		return null;
	}

	public ImageIcon getIconFromImageResource(String imageResourceId, int width, int height) {
		try {
			if (StringUtils.isEmpty(imageResourceId)) {
				return null;
			}
			ImageResource imageResource = ImageResourceDAO.getInstance().get(imageResourceId);
			if (imageResource != null) {
				return imageResource.getScaledImage(width, height);
			}
		} catch (Exception e0) {
			PosLog.error(DataProvider.class, e0);
		}
		return null;
	}

	public ImageResource getImageResource(String imageResourceId) {
		try {
			if (StringUtils.isBlank(imageResourceId)) {
				return null;
			}
			ImageResource imageResource = ImageResourceDAO.getInstance().findById(imageResourceId);
			if (imageResource != null) {
				return imageResource;
			}
		} catch (Exception e0) {
			PosLog.error(DataProvider.class, e0);
		}
		return null;
	}

	public void addCacheRefreshListener(CacheRefreshListener listener) {
		refreshListeners.add(listener);
	}

	public void removeCacheRefreshListener(CacheRefreshListener listener) {
		refreshListeners.remove(listener);
	}

	public void fireCacheRefreshed() {
		for (CacheRefreshListener cacheRefreshListener : refreshListeners) {
			cacheRefreshListener.cacheRefreshed();
		}
	}

	/**
	 * This method is here to help re-ordering old ticket using the following path:
	 * Dine IN->Customer selection view->Selected customer history view->Selected ticket order info->Reorder.
	 * 
	 * @return the ticket that should be created if reorder is selected.
	 */
	public Ticket getTicketToBeCreated() {
		return ticketToBeCreated;
	}

	/**
	 * This method is here to help re-ordering old ticket using the following path:
	 * Dine IN->Customer selection view->Selected customer history view->Selected ticket order info->Reorder.
	 * 
	 * @param ticket The ticket that should be created if reorder is selected.
	 */
	public void setTicketToBeCreated(Ticket ticket) {
		this.ticketToBeCreated = ticket;
	}

	public PrinterGroup getDefaultPrinterGroup() {
		return null;
	}

	public boolean isCaching(Class beanClass) {
		return false;
	}

	public User getUserById(String userId, String outletId) {
		return UserDAO.getInstance().get(userId, outletId);
	}

	public String getMqttDeviceId() {
		return TerminalUtil.getSystemUID();
	}
}
